==> spongeapi-8.0.0-20210211.013413-350-sources.jar: org/spongepowered/api/network/EngineConnection.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.network;

import net.kyori.adventure.text.Component;

/**
 * Represents a connection on the server or client engine.
 */
public interface EngineConnection extends RemoteConnection {

    /**
     * Gets the side this connection is on.
     *
     * @return The side
     */
    EngineConnectionSide<? extends EngineConnection> getSide();

    /**
     * Closes the connection, showing the default disconnect reason.
     * (the translation key {@code disconnect.disconnected})
     */
    @Override
    void close();

    /**
     * Closes the connection with the given reason.
     *
     * @param reason The reason for the disconnection
     */
    void close(Component reason);
}

==> spongeapi-8.0.0-20220108.065912-540-sources.jar: org/spongepowered/api/network/EngineConnection.java <==
/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.network;

import net.kyori.adventure.text.Component;

/**
 * Represents a connection on the server or client engine.
 */
public interface EngineConnection extends RemoteConnection {

    /**
     * Gets the side this connection is on.
     *
     * @return The side
     */
    EngineConnectionSide<? extends EngineConnection> side();

    /**
     * Closes the connection, showing the default disconnect reason.
     * (the translation key {@code disconnect.disconnected})
     */
    @Override
    void close();

    /**
     * Closes the connection with the given reason.
     *
     * @param reason The reason for the disconnection
     */
    void close(Component reason);
}
